@@ -213,6 +213,19 @@ class SQLPickle(object):
         return ((deserialise(row['key']), deserialise(row['value'])) for row in rows)
 
 
+    def pop(self, key, default = None):
+        """ D.pop(k[,d]) -> v, remove specified key and return the corresponding value.
+            If key is not found, d is returned if given, otherwise KeyError is raised
+        """
+        self._check_connection()
+
+        value = self.get(key, KeyError)
+        if value is KeyError:
+            raise KeyError(key);
+
+        q = "delete from %s where key = ?" % self._table_name
+        self._cursor.execute(q, (key,))
+        return value
 
 
     def commit(self):
