@@ -117,7 +117,22 @@ class TestSQLPickle(unittest.TestCase):
         self.assertEqual(list(p.items()), [('asdf', 66), ('rtyu', 99), ('qwer',77)])
 
 
+    def test_pop(self):
+        """ does pop() work?
+        """
+        p = sqlitepickle.SQLPickle()
+        key, value = 'asdf', 'qwer'
+        p.save(key, value)
+        p.save('rtyu', 2)
+        self.assertEqual(list(p.keys()), ['asdf', 'rtyu'])
+        self.assertEqual(list(p.items()), [('asdf', 'qwer'), ('rtyu', 2)])
 
+        value = p.pop('rtyu')
+        self.assertEqual(list(p.items()), [('asdf', 'qwer')])
+        self.assertEqual(value, 2)
+
+
+        self.assertRaises(KeyError, p.pop, 'rtyu')
 
 
     def xxtest_time(self):
